/* paths.h: Generated from texmf.cnf. */
#ifndef DEFAULT_TEXMFROOT
#define DEFAULT_TEXMFROOT "$SELFAUTOPARENT"
#endif

#ifndef DEFAULT_TEXMFDIST
#define DEFAULT_TEXMFDIST "/nonesuch"
#endif

#ifndef DEFAULT_TEXMFMAIN
#define DEFAULT_TEXMFMAIN "/nonesuch"
#endif

#ifndef DEFAULT_TEXMFLOCAL
#define DEFAULT_TEXMFLOCAL "$SELFAUTOGRANDPARENT/texmf-local"
#endif

#ifndef DEFAULT_TEXMFSYSVAR
#define DEFAULT_TEXMFSYSVAR "/nonesuch"
#endif

#ifndef DEFAULT_TEXMFSYSCONFIG
#define DEFAULT_TEXMFSYSCONFIG "/nonesuch"
#endif

#ifndef DEFAULT_TEXMFHOME
#define DEFAULT_TEXMFHOME "/nonesuch"
#endif

#ifndef DEFAULT_TEXMFVAR
#define DEFAULT_TEXMFVAR "/nonesuch"
#endif

#ifndef DEFAULT_TEXMFCONFIG
#define DEFAULT_TEXMFCONFIG "/nonesuch"
#endif

#ifndef DEFAULT_TEXMFAUXTREES
#define DEFAULT_TEXMFAUXTREES "/nonesuch"
#endif

#ifndef DEFAULT_TEXMF
#define DEFAULT_TEXMF "/nonesuch"
#endif

#ifndef DEFAULT_TEXMFDBS
#define DEFAULT_TEXMFDBS "/nonesuch"
#endif

#ifndef DEFAULT_SYSTEXMF
#define DEFAULT_SYSTEXMF "/nonesuch"
#endif

#ifndef DEFAULT_TEXMFCACHE
#define DEFAULT_TEXMFCACHE "/nonesuch"
#endif

#ifndef DEFAULT_VARTEXFONTS
#define DEFAULT_VARTEXFONTS "/nonesuch"
#endif

#ifndef DEFAULT_WEB2C
#define DEFAULT_WEB2C "/nonesuch"
#endif

#ifndef DEFAULT_TEXMFDOTDIR
#define DEFAULT_TEXMFDOTDIR "/nonesuch"
#endif

#ifndef DEFAULT_TEXINPUTS
#define DEFAULT_TEXINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_MFINPUTS
#define DEFAULT_MFINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_MPINPUTS
#define DEFAULT_MPINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_TEXFORMATS
#define DEFAULT_TEXFORMATS "/nonesuch"
#endif

#ifndef DEFAULT_MFBASES
#define DEFAULT_MFBASES "/nonesuch"
#endif

#ifndef DEFAULT_MPMEMS
#define DEFAULT_MPMEMS "/nonesuch"
#endif

#ifndef DEFAULT_TEXPOOL
#define DEFAULT_TEXPOOL "/nonesuch"
#endif

#ifndef DEFAULT_MFPOOL
#define DEFAULT_MFPOOL "/nonesuch"
#endif

#ifndef DEFAULT_MPPOOL
#define DEFAULT_MPPOOL "/nonesuch"
#endif

#ifndef DEFAULT_VFFONTS
#define DEFAULT_VFFONTS "/nonesuch"
#endif

#ifndef DEFAULT_TFMFONTS
#define DEFAULT_TFMFONTS "/nonesuch"
#endif

#ifndef DEFAULT_PKFONTS
#define DEFAULT_PKFONTS "/nonesuch"
#endif

#ifndef DEFAULT_GFFONTS
#define DEFAULT_GFFONTS "/nonesuch"
#endif

#ifndef DEFAULT_GLYPHFONTS
#define DEFAULT_GLYPHFONTS "/nonesuch"
#endif

#ifndef DEFAULT_MISCFONTS
#define DEFAULT_MISCFONTS "/nonesuch"
#endif

#ifndef DEFAULT_TEXFONTMAPS
#define DEFAULT_TEXFONTMAPS "/nonesuch"
#endif

#ifndef DEFAULT_BIBINPUTS
#define DEFAULT_BIBINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_BSTINPUTS
#define DEFAULT_BSTINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_MLBIBINPUTS
#define DEFAULT_MLBIBINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_MLBSTINPUTS
#define DEFAULT_MLBSTINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_RISINPUTS
#define DEFAULT_RISINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_BLTXMLINPUTS
#define DEFAULT_BLTXMLINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_MFTINPUTS
#define DEFAULT_MFTINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_TEXPSHEADERS
#define DEFAULT_TEXPSHEADERS "/nonesuch"
#endif

#ifndef DEFAULT_OSFONTDIR
#define DEFAULT_OSFONTDIR "/please/set/osfontdir/in/the/environment"
#endif

#ifndef DEFAULT_T1FONTS
#define DEFAULT_T1FONTS "/nonesuch"
#endif

#ifndef DEFAULT_AFMFONTS
#define DEFAULT_AFMFONTS "/nonesuch"
#endif

#ifndef DEFAULT_TTFONTS
#define DEFAULT_TTFONTS "/nonesuch"
#endif

#ifndef DEFAULT_OPENTYPEFONTS
#define DEFAULT_OPENTYPEFONTS "/nonesuch"
#endif

#ifndef DEFAULT_T42FONTS
#define DEFAULT_T42FONTS "/nonesuch"
#endif

#ifndef DEFAULT_LIGFONTS
#define DEFAULT_LIGFONTS "/nonesuch"
#endif

#ifndef DEFAULT_TEXCONFIG
#define DEFAULT_TEXCONFIG "/nonesuch"
#endif

#ifndef DEFAULT_INDEXSTYLE
#define DEFAULT_INDEXSTYLE "/nonesuch"
#endif

#ifndef DEFAULT_INDEXDICTIONARY
#define DEFAULT_INDEXDICTIONARY "/nonesuch"
#endif

#ifndef DEFAULT_ENCFONTS
#define DEFAULT_ENCFONTS "/nonesuch"
#endif

#ifndef DEFAULT_CMAPFONTS
#define DEFAULT_CMAPFONTS "/nonesuch"
#endif

#ifndef DEFAULT_SFDFONTS
#define DEFAULT_SFDFONTS "/nonesuch"
#endif

#ifndef DEFAULT_FONTFEATURES
#define DEFAULT_FONTFEATURES "/nonesuch"
#endif

#ifndef DEFAULT_FONTCIDMAPS
#define DEFAULT_FONTCIDMAPS "/nonesuch"
#endif

#ifndef DEFAULT_PDFTEXCONFIG
#define DEFAULT_PDFTEXCONFIG "/nonesuch"
#endif

#ifndef DEFAULT_TRFONTS
#define DEFAULT_TRFONTS "/usr{/local,}/share/groff/{current/font,site-font}/devps"
#endif

#ifndef DEFAULT_MPSUPPORT
#define DEFAULT_MPSUPPORT "/nonesuch"
#endif

#ifndef DEFAULT_MIMELIBDIR
#define DEFAULT_MIMELIBDIR "/nonesuch"
#endif

#ifndef DEFAULT_MAILCAPLIBDIR
#define DEFAULT_MAILCAPLIBDIR "/nonesuch"
#endif

#ifndef DEFAULT_FONTCONFIG_FILE
#define DEFAULT_FONTCONFIG_FILE "/nonesuch"
#endif

#ifndef DEFAULT_FONTCONFIG_PATH
#define DEFAULT_FONTCONFIG_PATH "/nonesuch"
#endif

#ifndef DEFAULT_FC_CACHEDIR
#define DEFAULT_FC_CACHEDIR "/nonesuch"
#endif

#ifndef DEFAULT_TEXDOCS
#define DEFAULT_TEXDOCS "/nonesuch"
#endif

#ifndef DEFAULT_TEXSOURCES
#define DEFAULT_TEXSOURCES "/nonesuch"
#endif

#ifndef DEFAULT_TEXMFLOCALEDIR
#define DEFAULT_TEXMFLOCALEDIR "/nonesuch"
#endif

#ifndef DEFAULT_WEBINPUTS
#define DEFAULT_WEBINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_CWEBINPUTS
#define DEFAULT_CWEBINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_OFMFONTS
#define DEFAULT_OFMFONTS "/nonesuch"
#endif

#ifndef DEFAULT_OPLFONTS
#define DEFAULT_OPLFONTS "/nonesuch"
#endif

#ifndef DEFAULT_OVFFONTS
#define DEFAULT_OVFFONTS "/nonesuch"
#endif

#ifndef DEFAULT_OVPFONTS
#define DEFAULT_OVPFONTS "/nonesuch"
#endif

#ifndef DEFAULT_OTPINPUTS
#define DEFAULT_OTPINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_OCPINPUTS
#define DEFAULT_OCPINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_T4HTINPUTS
#define DEFAULT_T4HTINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_TEX4HTFONTSET
#define DEFAULT_TEX4HTFONTSET "/nonesuch"
#endif

#ifndef DEFAULT_TEX4HTINPUTS
#define DEFAULT_TEX4HTINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_TW_LIBPATH
#define DEFAULT_TW_LIBPATH "/nonesuch"
#endif

#ifndef DEFAULT_TW_INIPATH
#define DEFAULT_TW_INIPATH "/nonesuch"
#endif

#ifndef DEFAULT_TTF2TFMINPUTS
#define DEFAULT_TTF2TFMINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_DVIPDFMXINPUTS
#define DEFAULT_DVIPDFMXINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_LUAINPUTS
#define DEFAULT_LUAINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_CLUAINPUTS
#define DEFAULT_CLUAINPUTS "$TEXMFDOTDIR:$SELFAUTOLOC/lib/{$progname,$engine,}/lua//"
#endif

#ifndef DEFAULT_TEXMFSCRIPTS
#define DEFAULT_TEXMFSCRIPTS "/nonesuch"
#endif

#ifndef DEFAULT_JAVAINPUTS
#define DEFAULT_JAVAINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_PERLINPUTS
#define DEFAULT_PERLINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_PYTHONINPUTS
#define DEFAULT_PYTHONINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_RUBYINPUTS
#define DEFAULT_RUBYINPUTS "/nonesuch"
#endif

#ifndef DEFAULT_TEXMFCNF
#define DEFAULT_TEXMFCNF "{$SELFAUTOLOC,$SELFAUTOLOC/share/texmf-local/web2c,$SELFAUTOLOC/share/texmf-dist/web2c,$SELFAUTOLOC/share/texmf/web2c,$SELFAUTOLOC/texmf-local/web2c,$SELFAUTOLOC/texmf-dist/web2c,$SELFAUTOLOC/texmf/web2c,$SELFAUTODIR,$SELFAUTODIR/share/texmf-local/web2c,$SELFAUTODIR/share/texmf-dist/web2c,$SELFAUTODIR/share/texmf/web2c,$SELFAUTODIR/texmf-local/web2c,$SELFAUTODIR/texmf-dist/web2c,$SELFAUTODIR/texmf/web2c,$SELFAUTOGRANDPARENT/texmf-local/web2c,$SELFAUTOPARENT,$SELFAUTOPARENT/share/texmf-local/web2c,$SELFAUTOPARENT/share/texmf-dist/web2c,$SELFAUTOPARENT/share/texmf/web2c,$SELFAUTOPARENT/texmf-local/web2c,$SELFAUTOPARENT/texmf-dist/web2c,$SELFAUTOPARENT/texmf/web2c}"
#endif

#ifndef DEFAULT_TEXMF_RESTRICTED_SCRIPTS
#define DEFAULT_TEXMF_RESTRICTED_SCRIPTS "/nonesuch"
#endif

#ifndef DEFAULT_MISSFONT_LOG
#define DEFAULT_MISSFONT_LOG "/nonesuch"
#endif

#ifndef DEFAULT_TEX_HUSH
#define DEFAULT_TEX_HUSH "/nonesuch"
#endif

#ifndef DEFAULT_TEX
#define DEFAULT_TEX "/nonesuch"
#endif

#ifndef DEFAULT_BIBTEX_CSFILE
#define DEFAULT_BIBTEX_CSFILE "/nonesuch"
#endif

